@@ -122,7 +122,9 @@ def _dispatch_select(
         # The following case is just an other security layers,
         # but we can't go in this case for the moment.
         case _:  # pragma: no cover
-            raise UnknownCommandTypeError(command.cmd_type.value)  # type: ignore
+            raise UnknownCommandTypeError(
+                command.cmd_type.value,  # type: ignore[attr-defined]
+            )
 
     return result
 
