@@ -5,7 +5,7 @@ from __future__ import annotations
 
 # Standard imports
 from dataclasses import dataclass, field, fields
-from typing import Any, Dict, List, Tuple, TypeAlias
+from typing import Any, TypeAlias
 
 # Third party imports
 from dotmap import DotMap
@@ -15,7 +15,7 @@ from psycopg import Connection
 from .enum import CommandTypeOrStr, Terminal
 
 
-def equality(obj: Any, other: Any) -> bool:
+def equality(obj: Any, other: Any) -> bool:  # noqa: ANN401
     """
     Try equality between two objects.
 
@@ -31,7 +31,7 @@ def equality(obj: Any, other: Any) -> bool:
     if not isinstance(other, type(obj)):
         return NotImplemented
 
-    for self_attr, other_attr in zip(fields(obj), fields(other)):
+    for self_attr, other_attr in zip(fields(obj), fields(other), strict=True):
         if not getattr(obj, self_attr.name) == getattr(other, other_attr.name):
             return False
 
@@ -56,7 +56,7 @@ class Command:
     cmd_type: CommandTypeOrStr
     args: DotMap = field(default_factory=DotMap)
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: Any) -> bool:  # noqa: ANN401
         """
         Try equality between two Command.
 
@@ -74,7 +74,7 @@ class Command:
 
         return True
 
-    def __ne__(self, other: Any) -> bool:
+    def __ne__(self, other: Any) -> bool:  # noqa: ANN401
         """
         Try no-equality between two Command.
 
@@ -110,7 +110,7 @@ class Flags:
     join: bool = False
     default_cmd: bool = False
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: Any) -> bool:  # noqa: ANN401
         """
         Try equality between two Flags.
 
@@ -118,7 +118,7 @@ class Flags:
         """
         return equality(self, other)
 
-    def __ne__(self, other: Any) -> bool:
+    def __ne__(self, other: Any) -> bool:  # noqa: ANN401
         """
         Try no-equality between two Flags.
 
@@ -154,7 +154,7 @@ class SQLEnumerableData:
 
     connection: Connection
     flags: Flags
-    cmd: List[Command]
+    cmd: list[Command]
     table: str | Any  # it's an SQLEnumerable
     length: int | None
 
@@ -164,5 +164,5 @@ class SQLEnumerableData:
 # ---------------
 
 PyLinqSqlInsertType: TypeAlias = (
-    Dict[str, Any] | List[Dict[str, Any]] | Tuple | List[Tuple]
+    dict[str, Any] | list[dict[str, Any]] | tuple | list[tuple]
 )
